#
# spec file for package python-docker-py
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define upstream_name docker-py
Name:           python-docker-py
Version:        1.10.4
Release:        1.1
Summary:        Docker API Client
License:        Apache-2.0
Group:          System/Management
Url:            https://pypi.python.org/pypi/docker-py
Source0:        https://pypi.io/packages/source/d/%{upstream_name}/%{upstream_name}-%{version}.tar.gz

# openSUSE-Patch hide_py_pckgmgmt.patch
Patch0:         hide_py_pckgmgmt.patch
Requires:       python-backports.ssl_match_hostname >= 3.5
Requires:       python-docker-pycreds >= 0.2.1
Requires:       python-ipaddress >= 1.0.16
Requires:       python-requests >= 2.5.3
Requires:       python-six >= 1.4.0
Requires:       python-websocket-client >= 0.32.0
BuildRequires:  fdupes
BuildRequires:  python-mock
BuildRequires:  python-pytest
BuildRequires:  python-pytest-cov
BuildRequires:  python-requests
BuildRequires:  python-setuptools
BuildRequires:  python-six
BuildRequires:  python-websocket-client
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
A docker API client in Python

%package test
Summary:        Unit tests
Group:          Development/Languages/Python
Requires:       %{name} == %{version}
Requires:       python-coverage >= 3.7.1
Requires:       python-flake8 >= 2.4.1
Requires:       python-mock >= 1.0.1
Requires:       python-pytest >= 2.7.2
Requires:       python-pytest-cov >= 2.1.0
Requires:       python-setuptools

%description test
Unit tests for docker-py

%prep
%setup -q -n %{upstream_name}-%{version}
%patch0 -p1

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
cp -r tests %{buildroot}/%{python_sitelib}/docker
%fdupes %{buildroot}

%check
#python tests/test.py

%files
%defattr(-,root,root,-)
%doc LICENSE README.md
%dir %{python_sitelib}/*
%exclude %{python_sitelib}/docker/tests/
%{python_sitelib}/docker/*
%{python_sitelib}/*egg-info/*

%files test
%defattr(-,root,root,-)
%dir %{python_sitelib}/docker/tests
%{python_sitelib}/docker/tests/*

%changelog
* Wed Oct 26 2016 jmassaguerpla@suse.com
- add python-dockerpycreds dependency in the spec file
  rebase hide_py_pckgmgmt.patch
  add fix-requirements.patch: fix dependencies so that they match the
  ones we have packaged
* Mon Oct 24 2016 jmassaguerpla@suse.com
- Update to version 1.10.4
  Bugfixes
    Fixed an issue where RestartPolicy.condition_types.ON_FAILURE would yield an invalid value.
    Fixed an issue where the SSL connection adapter would receive an invalid argument.
    Fixed an issue that caused the Client to fail to reach API endpoints when the provided base_url had a trailing slash.
    Fixed a bug where some environment values in create_container containing unicode characters would raise an encoding error.
    Fixed a number of issues tied with named pipe transport on Windows.
    Fixed a bug where inclusion patterns in .dockerignore would cause some excluded files to appear in the build context on Windows.
  Miscellaneous
    Adjusted version requirements for the requests library.
    It is now possible to run the docker-py test suite on Windows.
- Update to 1.10.3
  Bugfixes
    Fixed an issue where identity tokens in configuration files weren't handled by the library.
  Miscellaneous
    Increased the default number of connection pools from 10 to 25. This number can now be configured using the num_pools parameter in the Client constructor.
- Update to 1.10.2
  Bugfixes
    Updated the docker-pycreds dependency as it was causing issues for some users with dependency resolution in applications using docker-py.
- Update to 1.10.1
  Bugfixes
    The docker.utils.types module was removed in favor of docker.types, but some applications imported it explicitly. It has been re-added with an import warning advising to use the new module path.
- Update to 1.10.0
  Features
    Added swarm mode and service management methods. See the documentation for details.
    Added support for IPv6 Docker host addresses in the Client constructor.
    Added (read-only) support for the Docker credentials store.
    Added support for custom auth_config in Client.push.
    Added support for labels in Client.create_volume.
    Added support for labels and enable_ipv6 in Client.create_network.
    Added support for force param in Client.disconnect_container_from_network.
    Added support for pids_limit, sysctls, userns_mode, cpuset_cpus, cpu_shares, mem_reservation and kernel_memory parameters in Client.create_host_config.
    Added support for link_local_ips in create_endpoint_config.
    Added support for a changes parameter in Client.import_image.
    Added support for a version parameter in Client.from_env.
  Bugfixes
    Fixed a bug where Client.build would crash if the config.json file contained a HttpHeaders entry.
    Fixed a bug where passing decode=True in some streaming methods would crash when the daemon's response had an unexpected format.
    Fixed a bug where environment values with unicode characters weren't handled properly in create_container.
    Fixed a bug where using the npipe protocol would sometimes break with ValueError: buffer size must be strictly positive.
  Miscellaneous
    Fixed an issue where URL-quoting in docker-py was inconsistent with the quoting done by the Docker CLI client.
    The client now sends TCP upgrade headers to hint potential proxies about connection hijacking.
    The client now defaults to using the npipe protocol on Windows.
- Update to 1.9.0
  Features
    Added experimental support for Windows named pipes (npipe:// protocol).
    Added support for Block IO constraints in Client.create_host_config. This includes parameters blkio_weight, blkio_weight_device, device_read_bps, device_write_bps, device_read_iops and device_write_iops.
    Added support for the internal param in Client.create_network.
    Added support for ipv4_address and ipv6_address in utils function create_endpoint_config.
    Added support for custom user agent setting in the Client constructor. By default, docker-py now also declares itself in the User-Agent header.
  Bugfixes
    Fixed an issue where the HTTP timeout on streaming responses would sometimes be set incorrectly.
    Fixed an issue where explicit relative paths in .dockerignore files were not being recognized.
* Tue Sep 27 2016 tbechtold@suse.com
- Remove useless python-flake8 and python-coverage BuildRequires.
* Wed Jul 27 2016 jmassaguerpla@suse.com
- Update runtime requirements according to requirements.txt
* Mon Jul 25 2016 tboerger@suse.com
- Updated runtime and test deps matching setup.py and test-requirements.txt
- update to 1.8.1:
  * Fixed a bug where calling login() against the default registry would fail
    with the 1.10.x engine
  * Fixed a bug where values in environment files would be parsed incorrectly if
    they contained an equal sign.
  * Switched to a better supported backport of the match_hostname function,
    fixing dependency issues in some environments.
- update to 1.8.0:
  * Added Client.update_container method (Update resource configs of a
    container)
  * Added support for gzipped context in Client.build
  * Added ability to specify IP address when connecting a container to a network
  * Added tmpfs support to Client.create_host_config
  * Added support for the changes param in Client.commit
  * Added support for the follow param in Client.logs
  * Added support for the check_duplicate param in Client.create_network
  * Added support for the decode param in Client.push and Client.pull
  * Added docker.from_env shortcut function. Instantiates a client with
    kwargs_from_env
  * kwargs_from_env now supports an optional environment parameter. If present,
    values will be fetched from this dictionary instead of os.environ
  * Fixed a bug where TLS verification would fail when using IP addresses in the
    certificate's subjectAltName fields
  * Fixed an issue where the default TLS version in TLSConfig would break in
    some environments. docker-py now uses TLSv1 by default This setting can be
    overridden using the ssl_version param in kwargs_from_env or the TLSConfig
    constructor
  * Fixed a bug where tcp hosts would fail to connect to TLS-enabled endpoints
  * Fixed a bug where loading a valid docker configuration file would fail
  * Fixed a bug where some environment variables specified through
    create_container would be improperly formatted
  * Fixed a bug where using the unix socket connection would raise an error in
    some edge-case situations
  * Default API version is now 1.22 (introduced in Docker 1.10.0)
* Sun Feb 28 2016 dmueller@suse.com
- update to 1.7.2:
  * Added support for the since param in Client.logs (introduced in API version 1.19)
  * Added support for the DOCKER_CONFIG environment variable when looking up auth config
  * Added support for the stream param in Client.stats (when set to False, allows user to retrieve a single snapshot instead of a constant data stream)
  * Added support for the mem_swappiness, oom_kill_disable params in Client.create_host_config
  * Added support for build arguments in Client.build through the buildargs param.
  * Added support for cusom IPAM configuration in Client.create_network
  * Added input support to Client.exec_create
  * Added support for stop_signal in Client.create_host_config
  * Added support for custom HTTP headers in Docker config file.
  * Added support for unspecified transfer protocol in base_url when TLS is enabled.
  * Fixed a bug where TLS verification was improperly executed when providing a custom CA certificate.
  * Added support for shm_size in Client.create_host_config
- drop dockpyTest_pathAdd.patch: tests are disabled anyway
* Sat Nov 14 2015 rjschwei@suse.com
- Use version 1.5.0 in SLE 12 (bnc#954486,bnc#954690)
  + A bit of clean up of the changes file as well, no wrapping comments
* Wed Oct 21 2015 dmueller@suse.com
- update to 1.5.0:
  * Added support for the networking API introduced in Docker 1.9.0
  * Added support for the volumes API introduced in Docker 1.9.0
  * Added support for the group_add parameter in create_host_config.
  * Added support for the CPU CFS (cpu_quota and cpu_period) parameteres
    in create_host_config.
  * Added support for the archive API endpoint (Client.get_archive,
    Client.put_archive).
  * Added support for ps_args parameter in Client.top.
  * Added utils.parse_env_file to support env-files. See docs for usage.
  * Added support for arbitrary log drivers
  * Added support for URL paths in the docker host URL (base_url)
  * Fixed a bug where exec_inspect would allow invocation when the API
    version was too low.
  * Fixed a bug where docker.utils.ports.split_port would break if an
    open range was provided.
  * Fixed a bug where invalid image IDs / container IDs could be provided
    to bypass or reroute request URLs
* Fri Aug 14 2015 jmassaguerpla@suse.com
- Get source tarball from pypi.python.org as in previuos versions
  and as it is in the spec file
* Mon Jul 27 2015 hvogel@suse.com
- Update to version 1.3.1. Detailed changelog:
  https://github.com/docker/docker-py/blob/master/docs/change_log.md#131
* Mon May  4 2015 benoit.monin@gmx.fr
- update to version 1.2.1:
  * Fixed a bug where the check_resource decorator would break with
    some argument-passing methods. (#573)
- additional changes from version 1.2.0:
  * Client.execute is being deprecated in favor of the more
    dev-friendly Client.exec_start and Client.exec_create. It will
    be removed in 1.3.0
  * Added exec_create, exec_start, exec_inspect and exec_resize to
    client, accurately mirroring the Exec API
  * Added auth_config param to Client.pull (allows to use one-off
    credentials for this pull request)
  * Added support for ipc_mode in host config.
  * Added support for the log_config param in host config.
  * Added support for the ulimit param in host config.
  * Added support for container resource limits in Client.build.
  * When a resource identifier (image or container ID) is passed to
    a Client method, we now check for None values to avoid crashing
    (now raises docker.errors.NullResource)
  * Added tools to parse port ranges inside the new
    docker.utils.ports package.
  * Added a version_info attribute to the docker package.
  * Fixed a bug in Client.port where absence of a certain key in
    the container's JSON would raise an error (now just returns
    None)
  * Fixed a bug with the trunc parameter in Client.containers
    having no effect (moved functionality to the client)
  * Several improvements have been made to the Client.import_image
    method.
  * Fixed pushing / pulling to v2 registries
  * Fixed a bug where passing a container dictionary to
    Client.commit would fail
  * Default API version has been bumped to 1.18 (Docker Engine
    1.6.0)
  * Several testing coverage improvements
  * Docs fixes and improvements
- point the source URL to pypi
- add a dependency between the test sub-package and
  python-docker-py
* Thu Apr  9 2015 fcastelli@suse.com
- Updated to 1.1.0
  * Features
  * Added `dockerfile` param support to `Client.build` (mirrors
    `docker build -f` behavior)
  * Added the ability to specify `'auto'` as `version` in `Client.__init__`,
    allowing the constructor to autodetect the daemon's API version.
  * Bugfixes
  * Fixed a bug where decoding a result stream using the `decode` parameter
    would break when using Python 3.x
  * Fixed a bug where some files in `.dockerignore` weren't being handled
    properly
  * Fixed `resolve_authconfig` issues by bringing it closer to Docker Engine's
    behavior. This should fix all issues encountered with private registry auth
  * Fixed an issue where passwords containing a colon weren't being handled
    properly.
  * Bumped `requests` version requirement, which should fix most of the SSL
    issues encountered recently.
  * Miscellaneous
  * Several integration test improvements.
  * Fixed some unclosed resources in unit tests.
  * Several docs improvements.
- Version 1.0.0
  * Features
  * Added new `Client.rename` method (`docker rename`)
  * Added now `Client.stats` method (`docker stats`)
  * Added `read_only` param support to `utils.create_host_config` and
    `Client.start` (`docker run --read-only`)
  * Added `pid_mode` param support to `utils.create_host_config` and
    `Client.start` (`docker run --pid='host'`)
  * Added `since`, `until` and `filters` params to `Client.events`.
  * Added `decode` parameter to `Client.stats` and `Client.events` to decode
    JSON objects on the fly (False by default).
- Bugfixes
  * Fixed a bug that caused `Client.build` to crash when the provided source was
    a remote source.
- Miscellaneous
  * Default API version has been bumped to 1.17 (Docker Engine 1.5.0)
  * `Client.timeout` is now a public attribute, and users are encouraged to use it
    when request timeouts need to be changed at runtime.
  * Added `Client.api_version` as a read-only property.
  * The `memswap_limit` argument in `Client.create_container` now accepts string
    type values similar to `mem_limit` ('6g', '120000k', etc.)
  * Improved documentation
- Version 0.7.2
  * Features
  * Added support for `mac_address` in `Client.create_container`
  * Bugfixes
  * Fixed a bug where streaming responses (`pull`, `push`, `logs`, etc.) were
    unreliable (#300)
  * Fixed a bug where resolve_authconfig wouldn't properly resolve configuration
    for private repositories (#468)
  * Fixed a bug where some errors wouldn't be properly constructed in
    `client.py`, leading to unhelpful exceptions bubbling up (#466)
  * Fixed a bug where `Client.build` would try to close context when externally
    provided (`custom_context == True`) (#458)
  * Fixed an issue in `create_host_config` where empty sequences wouldn't be
    interpreted properly (#462)
  * Miscellaneous
  * Added `resolve_authconfig` tests.
- Version 0.7.1
  * Bugfixes
  * `setup.py` now indicates a maximum version of requests to work around the
    boot2docker / `assert_hostname` bug.
  * Removed invalid exception when using the Registry Hub's FQDN when pulling.
  * Fixed an issue where early HTTP errors weren't handled properly in streaming
    responses.
  * Fixed a bug where sockets would close unexpectedly using Python 3.x
  * Various fixes for integration tests.
  * Miscellaneous
  * Small doc fixes
- Version 0.7.0
  * Breaking changes
  * Passing `dns` or `volumes_from` in `Client.start` with API version < 1.10
    will now raise an exception (previously only triggered a warning)
  * Features
  * Added support for `host_config` in `Client.create_container`
  * Added utility method `docker.utils.create_host_config` to help build a
    proper `HostConfig` dictionary.
  * Added support for the `pull` parameter in `Client.build`
  * Added support for the `forcerm` parameter in `Client.build`
  * Added support for `extra_hosts` in `Client.start`
  * Added support for a custom `timeout` in `Client.wait`
  * Added support for custom `.dockercfg` loading in `Client.login`
    (`dockercfg_path` argument)
  * Bugfixes
  * Fixed a bug where some output wouldn't be streamed properly in streaming
    chunked responses
  * Fixed a bug where the `devices` param didn't recognize the proper delimiter
  * `Client.login` now properly expands the `registry` URL if provided.
  * Fixed a bug where unicode characters in passed for `environment` in
    `create_container` would break.
  * Miscellaneous
  * Several unit tests and integration tests improvements.
  * `Client` constructor now enforces passing the `version` parameter as a
    string.
  * Build context files are now ordered by filename when creating the archive
    (for consistency with docker mainline behavior)
- Version 0.6.0
  * **This version introduces breaking changes!**
  * Breaking changes
  * The default SSL protocol is now the highest TLS v1.x (was SSL v2.3 before)
    (Poodle fix)
  * The `history` command now returns a dict instead of a raw JSON string.
  * Features
  * Added the `execute` command.
  * Added `pause` and `unpause` commands.
  * Added support fo the `cpuset` param in `create_container`
  * Added support for host devices (`devices` param in `start`)
  * Added support for the `tail` param in `logs`.
  * Added support for the `filters` param in `images` and `containers`
  * The `kwargs_from_env` method is now available in the `docker.utils`
    module. This should make it easier for boot2docker user to connect
    to their daemon.
  * Bugfixes
  * Fixed a bug where empty directories weren't correctly included when
    providing a context to `Client.build`.
  * Fixed a bug where UNIX socket connections weren't properly cleaned up,
    causing `ResourceWarning`s to appear in some cases.
  * Fixed a bug where docker-py would crash if the docker daemon was stopped
    while reading a streaming response
  * Fixed a bug with streaming responses in Python 3
  * `remove_image` now supports a dict containing an `Id` key as its `id`
    parameter (similar to other methods requiring a resource ID)
  * Documentation
  * Added new MkDocs documentation. Currently hosted on
    [ReadTheDocs](http://docker-py.readthedocs.org/en/latest/)
  * Miscellaneous
  * Added tests to sdist
  * Added a Makefile for running tests in Docker
  * Updated Dockerfile
* Wed Mar  4 2015 rjschwei@suse.com
- Use updated version in SLES 12 in support of bnc#915479
* Sun Feb  8 2015 rjschwei@suse.com
- Update to version 0.5.3  - Contains breaking changes
  * Fixed attaching when connecting to the daemon over a UNIX socket.
  * Fixed a bug where sockets were closed immediately when attaching over
    TLS.
  * Added a `assert_hostname` option to `TLSConfig` which can be used to
    disable verification of hostnames.
  * Fixed SSL not working due to an incorrect version comparison
  * Fixed streams not working on Windows
  * Added `insecure_registry` parameter in `Client.push` and `Client.pull`.
    + It defaults to False and code pushing to non-HTTPS private registries
    might break as a result.*
  * Added support for adding and dropping capabilities
  * Added support for restart policy
  * Added support for string values in `Client.create_container`'s `mem_limit`
  * Added support for `.dockerignore` file in `Client.build`
  * Fixed timeout behavior in `Client.stop`
  * `Client.create_container` provides better validation of the `volumes`
    parameter
  * Improved integration tests
- Enable run of some of the tests
  * add: dockpyTest_pathAdd.patch
- Create test subpackage
* Wed Aug  6 2014 fcastelli@suse.com
- Update to version 0.4.0:
  * This version introduces breaking changes!
  * The base_url parameter in the Client constructor should now allow most of
    the DOCKER_HOST environment values (except for the fd:// protocol)
    As a result, URLs that don't specify a port are now invalid (similar to
    the official client's behavior)
  * Added TLS support (see documentation)
  * Fixed an issue with Client.build streamed logs in Python 3
  * Added unit tests coverage
  * Various integration tests fixes
- Changes introduced by version 0.3.2:
  * Default API version is now 1.12 (support for docker 1.0)
  * Added new methods Client.get_image and Client.load_image (docker save and
    docker load)
  * Added new method Client.ping
  * Added new method Client.resize
  * Client.build can now be provided with a custom context using the
    custom_context parameter.
  * Added support for memswap_limit parameter in create_container
  * Added support for force parameter in remove_container
  * Added support for force and noprune parameters in remove_image
  * Added support for timestamps parameter in logs
  * Added support for dns_search parameter in start
  * Added support for network_mode parameter in start
  * Added support for size parameter in containers
  * Added support for volumes_from and dns parameters in start.
    As of API version >= 1.10, these parameters no longer belong to create_container
  * Client.logs now uses the logs endpoint when API version is sufficient
  * Fixed a bug in pull where the repo:tag notation wasn't interpreted properly
  * Fixed a bug in streaming methods with python 3 (unicode, bytes/str related)
  * Fixed a bug in Client.start where legacy notation for volumes wasn't supported anymore.
  * The client now raises DockerExceptions when appropriate. You can import
    DockerException (and its subclasses) from the docker.errors module to
    catch them if needed.
  * docker.APIError has been moved to the new docker.errors module as well.
  * Client.insert is deprecated in API version > 1.11
  * Improved integration tests should now run much faster.
  * There is now a single source of truth for the docker-py version number.
* Mon Jun 16 2014 rschweikert@suse.com
- Clean up spec file
* Fri Jun  6 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #316168)
* Thu Jun  5 2014 rschweikert@suse.com
- Initial build
